==> misfortune-0.1.2.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-5K0VLxPN3Kh20dMoViHuJM
key:                  misfortune-0.1.2.1-5K0VLxPN3Kh20dMoViHuJM
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  b04f7ac5adb43d7741426c888f082610
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.0.2/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-5K0VLxPN3Kh20dMoViHuJM
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6 directory-1.3.6.2
    filepath-1.4.2.1 knob-0.2.2-1ypFll9vgdD70mKIeOuazM
    random-1.2.1.1-7p3S1HZR5GbCV1ZhMXz9LL
    random-fu-0.3.0.1-ILi2P1ovlxlCJp863z9326 text-1.2.5.0
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.13.0.0-AvCgqYhQ3vmCYiPnKivqd

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> misfortune-0.1.2.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-FfMHgd09XcT8wzQo9Pk4Ci
key:                  misfortune-0.1.2.1-FfMHgd09XcT8wzQo9Pk4Ci
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  8d338435ef5dca3d2eba49f64e527a83
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.0.2/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-FfMHgd09XcT8wzQo9Pk4Ci
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6 directory-1.3.6.2
    filepath-1.4.2.1 knob-0.2.2-1ypFll9vgdD70mKIeOuazM
    random-1.2.1.1-K0OGGZ2RgxUBJhcMzCddDt
    random-fu-0.3.0.1-GwbXSvIy1Mp9qGs9xPokz1 text-1.2.5.0
    utf8-string-1.0.2-519AraujIYSLY3i7TJuoqO
    vector-0.13.0.0-9fyHsAonVFcGYv9jtLmfSh

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
